==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Autofill/Autofill.js <==
import '../node_modules/core-js/modules/es.array.index-of.js';
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { KeyCodes, isIE11 } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var SELECTION_FORWARD = 'forward';

var Autofill = function (_BaseComponent) {
  _inherits(Autofill, _BaseComponent);

  var _super = _createSuper(Autofill);

  function Autofill() {
    var _this;

    _classCallCheck(this, Autofill);

    _this = _super.apply(this, arguments);
    _this.autoFillEnabled = false;
    _this.isComposing = false;
    _this.internalValue = _this.defaultVisibleValue || '';
    _this.displayValue = _this.defaultVisibleValue || '';
    return _this;
  }

  _createClass(Autofill, [{
    key: "focus",
    value: function focus() {
      this.$refs.inputElement && this.$refs.inputElement.focus();
    }
  }, {
    key: "clear",
    value: function clear() {
      this.autoFillEnabled = true;
      this.updateValue('', false);
      this.$refs.inputElement && this.$refs.inputElement.setSelectionRange(0, 0);
    }
  }, {
    key: "onKeyDown",
    value: function onKeyDown(ev) {
      this.$emit('keydown', ev);

      if (!ev.isComposing) {
        switch (ev.which) {
          case KeyCodes.backspace:
            this.autoFillEnabled = false;
            break;

          case KeyCodes.left:
          case KeyCodes.right:
            if (this.autoFillEnabled) {
              this.internalValue = this.displayValue;
              this.autoFillEnabled = false;
            }

            break;

          default:
            if (!this.autoFillEnabled) {
              if (this.enableAutofillOnKeyPress.indexOf(ev.which) !== -1) {
                this.autoFillEnabled = true;
              }
            }

            break;
        }
      }
    }
  }, {
    key: "onInputChanged",
    value: function onInputChanged(ev) {
      var value = this.getCurrentInputValue(ev);

      if (!this.isComposing) {
        this.tryEnableAutofill(value, this.value, ev.isComposing);
      }

      if (!(isIE11() && this.isComposing)) {
        var nativeEventComposing = ev.composed;
        var isComposing = nativeEventComposing === undefined ? this.isComposing : nativeEventComposing;
        this.updateValue(value, isComposing);
      }
    }
  }, {
    key: "getCurrentInputValue",
    value: function getCurrentInputValue(ev) {
      if (ev && ev.target && ev.target.value) {
        return ev.target.value;
      } else if (this.$refs.inputElement && this.$refs.inputElement.value) {
        return this.$refs.inputElement.value;
      } else {
        return '';
      }
    }
  }, {
    key: "updateValue",
    value: function updateValue(newValue, composing) {
      if (!newValue && newValue === this.value) {
        return;
      }

      this.internalValue = this.onInputChange ? this.onInputChange(newValue, composing) : newValue;
      this.displayValue = this.getDisplayValue(this.value, this.suggestedDisplayValue);
    }
  }, {
    key: "getDisplayValue",
    value: function getDisplayValue(inputValue, suggestedDisplayValue) {
      var displayValue = inputValue;

      if (suggestedDisplayValue && inputValue && this.doesTextStartWith(suggestedDisplayValue, displayValue) && this.autoFillEnabled) {
        displayValue = suggestedDisplayValue;
      }

      return displayValue;
    }
  }, {
    key: "doesTextStartWith",
    value: function doesTextStartWith(text, startWith) {
      if (!text || !startWith) {
        return false;
      }

      return text.toLocaleLowerCase().indexOf(startWith.toLocaleLowerCase()) === 0;
    }
  }, {
    key: "tryEnableAutofill",
    value: function tryEnableAutofill(newValue, oldValue, isComposing, isComposed) {
      if (!isComposing && newValue && this.$refs.inputElement && this.$refs.inputElement.selectionStart === newValue.length && !this.autoFillEnabled && (newValue.length > oldValue.length || isComposed)) {
        this.autoFillEnabled = true;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var h = arguments[0];
      var displayValue = this.displayValue;
      return h("input", {
        "ref": "inputElement",
        "attrs": {
          "autoCapitalize": "off",
          "autoComplete": "off",
          "aria-autocomplete": 'both',
          "data-lpignore": true
        },
        "domProps": {
          "value": displayValue
        },
        "on": {
          "input": this.onInputChanged,
          "keydown": this.onKeyDown,
          "click": function click(ev) {
            return _this2.$emit('click', ev);
          }
        }
      });
    }
  }, {
    key: "cursorLocation",
    get: function get() {
      if (this.$refs.inputElement) {
        var inputElement = this.$refs.inputElement;

        if (inputElement.selectionDirection !== SELECTION_FORWARD) {
          return inputElement.selectionEnd;
        } else {
          return inputElement.selectionStart;
        }
      } else {
        return -1;
      }
    }
  }, {
    key: "value",
    get: function get() {
      return this.internalValue;
    }
  }, {
    key: "isValueSelected",
    get: function get() {
      return Boolean(this.$refs.inputElement && this.$refs.inputElement.selectionStart !== this.$refs.inputElement.selectionEnd);
    }
  }, {
    key: "selectionStart",
    get: function get() {
      return this.$refs.inputElement ? this.$refs.inputElement.selectionStart : -1;
    }
  }, {
    key: "selectionEnd",
    get: function get() {
      return this.$refs.inputElement ? this.$refs.inputElement.selectionEnd : -1;
    }
  }]);

  return Autofill;
}(BaseComponent);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], Autofill.prototype, "defaultVisibleValue", void 0);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], Autofill.prototype, "suggestedDisplayValue", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], Autofill.prototype, "preventValueSelection", void 0);

__decorate([Prop({
  type: Array,
  "default": function _default() {
    return [KeyCodes.down, KeyCodes.up];
  }
}), __metadata("design:type", Array)], Autofill.prototype, "enableAutofillOnKeyPress", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], Autofill.prototype, "onInputChange", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], Autofill.prototype, "onInputValueChange", void 0);

Autofill = __decorate([Component], Autofill);

export { Autofill };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Autofill/Autofill.js <==
import 'core-js/modules/es.array.index-of';
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { KeyCodes, isIE11 } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var SELECTION_FORWARD = 'forward';

var Autofill = function (_BaseComponent) {
  _inherits(Autofill, _BaseComponent);

  var _super = _createSuper(Autofill);

  function Autofill() {
    var _this;

    _classCallCheck(this, Autofill);

    _this = _super.apply(this, arguments);
    _this.autoFillEnabled = false;
    _this.isComposing = false;
    _this.internalValue = _this.defaultVisibleValue || '';
    _this.displayValue = _this.defaultVisibleValue || '';
    return _this;
  }

  _createClass(Autofill, [{
    key: "focus",
    value: function focus() {
      this.$refs.inputElement && this.$refs.inputElement.focus();
    }
  }, {
    key: "clear",
    value: function clear() {
      this.autoFillEnabled = true;
      this.updateValue('', false);
      this.$refs.inputElement && this.$refs.inputElement.setSelectionRange(0, 0);
    }
  }, {
    key: "onKeyDown",
    value: function onKeyDown(ev) {
      this.$emit('keydown', ev);

      if (!ev.isComposing) {
        switch (ev.which) {
          case KeyCodes.backspace:
            this.autoFillEnabled = false;
            break;

          case KeyCodes.left:
          case KeyCodes.right:
            if (this.autoFillEnabled) {
              this.internalValue = this.displayValue;
              this.autoFillEnabled = false;
            }

            break;

          default:
            if (!this.autoFillEnabled) {
              if (this.enableAutofillOnKeyPress.indexOf(ev.which) !== -1) {
                this.autoFillEnabled = true;
              }
            }

            break;
        }
      }
    }
  }, {
    key: "onInputChanged",
    value: function onInputChanged(ev) {
      var value = this.getCurrentInputValue(ev);

      if (!this.isComposing) {
        this.tryEnableAutofill(value, this.value, ev.isComposing);
      }

      if (!(isIE11() && this.isComposing)) {
        var nativeEventComposing = ev.composed;
        var isComposing = nativeEventComposing === undefined ? this.isComposing : nativeEventComposing;
        this.updateValue(value, isComposing);
      }
    }
  }, {
    key: "getCurrentInputValue",
    value: function getCurrentInputValue(ev) {
      if (ev && ev.target && ev.target.value) {
        return ev.target.value;
      } else if (this.$refs.inputElement && this.$refs.inputElement.value) {
        return this.$refs.inputElement.value;
      } else {
        return '';
      }
    }
  }, {
    key: "updateValue",
    value: function updateValue(newValue, composing) {
      if (!newValue && newValue === this.value) {
        return;
      }

      this.internalValue = this.onInputChange ? this.onInputChange(newValue, composing) : newValue;
      this.displayValue = this.getDisplayValue(this.value, this.suggestedDisplayValue);
    }
  }, {
    key: "getDisplayValue",
    value: function getDisplayValue(inputValue, suggestedDisplayValue) {
      var displayValue = inputValue;

      if (suggestedDisplayValue && inputValue && this.doesTextStartWith(suggestedDisplayValue, displayValue) && this.autoFillEnabled) {
        displayValue = suggestedDisplayValue;
      }

      return displayValue;
    }
  }, {
    key: "doesTextStartWith",
    value: function doesTextStartWith(text, startWith) {
      if (!text || !startWith) {
        return false;
      }

      return text.toLocaleLowerCase().indexOf(startWith.toLocaleLowerCase()) === 0;
    }
  }, {
    key: "tryEnableAutofill",
    value: function tryEnableAutofill(newValue, oldValue, isComposing, isComposed) {
      if (!isComposing && newValue && this.$refs.inputElement && this.$refs.inputElement.selectionStart === newValue.length && !this.autoFillEnabled && (newValue.length > oldValue.length || isComposed)) {
        this.autoFillEnabled = true;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var h = arguments[0];
      var displayValue = this.displayValue;
      return h("input", {
        "ref": "inputElement",
        "attrs": {
          "autoCapitalize": "off",
          "autoComplete": "off",
          "aria-autocomplete": 'both',
          "data-lpignore": true
        },
        "domProps": {
          "value": displayValue
        },
        "on": {
          "input": this.onInputChanged,
          "keydown": this.onKeyDown,
          "click": function click(ev) {
            return _this2.$emit('click', ev);
          }
        }
      });
    }
  }, {
    key: "cursorLocation",
    get: function get() {
      if (this.$refs.inputElement) {
        var inputElement = this.$refs.inputElement;

        if (inputElement.selectionDirection !== SELECTION_FORWARD) {
          return inputElement.selectionEnd;
        } else {
          return inputElement.selectionStart;
        }
      } else {
        return -1;
      }
    }
  }, {
    key: "value",
    get: function get() {
      return this.internalValue;
    }
  }, {
    key: "isValueSelected",
    get: function get() {
      return Boolean(this.$refs.inputElement && this.$refs.inputElement.selectionStart !== this.$refs.inputElement.selectionEnd);
    }
  }, {
    key: "selectionStart",
    get: function get() {
      return this.$refs.inputElement ? this.$refs.inputElement.selectionStart : -1;
    }
  }, {
    key: "selectionEnd",
    get: function get() {
      return this.$refs.inputElement ? this.$refs.inputElement.selectionEnd : -1;
    }
  }]);

  return Autofill;
}(BaseComponent);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], Autofill.prototype, "defaultVisibleValue", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], Autofill.prototype, "suggestedDisplayValue", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], Autofill.prototype, "preventValueSelection", void 0);

__decorate([Prop({
  type: Array,
  default: function _default() {
    return [KeyCodes.down, KeyCodes.up];
  }
}), __metadata("design:type", Array)], Autofill.prototype, "enableAutofillOnKeyPress", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], Autofill.prototype, "onInputChange", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], Autofill.prototype, "onInputValueChange", void 0);

Autofill = __decorate([Component], Autofill);

export { Autofill };
